@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #include "GmshConfig.h"
 
@@ -130,7 +130,7 @@ void Msg::Init(int argc, char **argv)
   // prune argv from gmsh-specific options that make PETSc verbose
   for(int i = 0; i < argc; i++){
     std::string val(argv[i]);
-    if(val != "-info" && val != "-help" && val != "-v")
+    if(val != "-info" && val != "-help" && val != "-version")
       sargv[sargc++] = argv[i];
   }
   PetscInitialize(&sargc, &sargv, PETSC_NULL, PETSC_NULL);
