@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #ifndef _GENTITY_H_
 #define _GENTITY_H_
@@ -290,8 +290,8 @@ public:
   }
   virtual std::vector<int> getPhysicalEntities() { return physicals; }
 
-  // returns the master entity (for mesh)
-  GEntity *meshMaster() const;
+  // handle the master entity for periodic meshes
+  GEntity *getMeshMaster() const { return _meshMaster; }
   void setMeshMaster(GEntity *);
   void setMeshMaster(GEntity *, const std::vector<double> &);
   void updateCorrespondingVertices();
