@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #include <sstream>
 #include "GmshConfig.h"
@@ -39,6 +39,7 @@ GFace::GFace(GModel *model, int tag)
   : GEntity(model, tag), r1(0), r2(0), va_geom_triangles(0)
 {
   meshStatistics.status = GFace::PENDING;
+  meshStatistics.refineAllEdges = false;
   resetMeshAttributes();
 }
 
@@ -78,11 +79,16 @@ int GFace::getMeshingAlgo() const
            it->second;
 }
 
-void GFace::setMeshingAlgo(int algo)
+void GFace::setMeshingAlgo(int algo) const
 {
   CTX::instance()->mesh.algo2dPerFace[tag()] = algo;
 }
 
+void GFace::unsetMeshingAlgo() const
+{
+  CTX::instance()->mesh.algo2dPerFace.erase(tag());
+}
+
 void GFace::delFreeEdge(GEdge *edge)
 {
   // delete the edge from the edge list and the orientation list
@@ -1526,6 +1532,12 @@ static void meshCompound(GFace *gf, bool verbose)
 
 void GFace::mesh(bool verbose)
 {
+  if(CTX::instance()->debugSurface > 0 &&
+     tag() != CTX::instance()->debugSurface) {
+    meshStatistics.status = GFace::DONE;
+    return;
+  }
+
 #if defined(HAVE_MESH)
   meshGFace mesher;
   mesher(this, verbose);
@@ -1759,7 +1771,7 @@ void GFace::setMeshMaster(GFace *master, const std::vector<double> &tfo)
     }
     GEdge *masterEdge = mv2eIter->second;
 
-    if(masterEdge->meshMaster() != localEdge) {
+    if(masterEdge->getMeshMaster() != localEdge) {
       localEdge->setMeshMaster(masterEdge, tfo);
       Msg::Info("Setting edge master %d - %d", localEdge->tag(),
                 masterEdge->tag());
@@ -2123,7 +2135,7 @@ bool GFace::reorder(const int elementType, const std::vector<int> &ordering)
 
 void GFace::alignElementsWithMaster()
 {
-  GEntity *master = meshMaster();
+  GEntity *master = getMeshMaster();
 
   if(master != this) {
     std::set<MFace, Less_Face> srcFaces;
