@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #ifndef _GFACE_H_
 #define _GFACE_H_
@@ -319,13 +319,15 @@ public:
   } meshAttributes;
 
   int getMeshingAlgo() const;
-  void setMeshingAlgo(int);
+  void setMeshingAlgo(int) const;
+  void unsetMeshingAlgo() const;
   int getCurvatureControlParameter() const;
   void setCurvatureControlParameter(int);
   virtual double getMeshSize() const { return meshAttributes.meshSize; }
 
   struct {
     mutable GEntity::MeshGenerationStatus status;
+    bool refineAllEdges;
     double worst_element_shape, best_element_shape, average_element_shape;
     double smallest_edge_length, longest_edge_length, efficiency_index;
     int nbEdge, nbTriangle;
