@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #ifndef _GEO_DEFINES_H_
 #define _GEO_DEFINES_H_
@@ -16,7 +16,6 @@ public:
 #define MSH_POINT 100
 #define MSH_POINT_BND_LAYER 101
 #define MSH_POINT_DISCRETE 102
-#define MSH_POINT_FROM_GMODEL 103
 
 #define MSH_SEGM_LINE 200
 #define MSH_SEGM_SPLN 201
@@ -30,7 +29,6 @@ public:
 #define MSH_SEGM_BEZIER 209
 #define MSH_SEGM_BND_LAYER 211
 #define MSH_SEGM_DISCRETE 212
-#define MSH_SEGM_FROM_GMODEL 213
 
 #define MSH_SURF_PLAN 300
 #define MSH_SURF_REGL 301
@@ -38,11 +36,9 @@ public:
 #define MSH_SURF_BND_LAYER 303
 #define MSH_SURF_LOOP 304
 #define MSH_SURF_DISCRETE 305
-#define MSH_SURF_FROM_GMODEL 306
 
 #define MSH_VOLUME 400
 #define MSH_VOLUME_DISCRETE 401
-#define MSH_VOLUME_FROM_GMODEL 402
 
 #define MSH_PHYSICAL_POINT 500
 #define MSH_PHYSICAL_LINE 501
