@@ -1,14 +1,13 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #ifndef _DISCRETE_EDGE_H_
 #define _DISCRETE_EDGE_H_
 
 #include "GModel.h"
 #include "GEdge.h"
-#include "discreteVertex.h"
 
 class discreteEdge : public GEdge {
 protected:
