@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #ifndef _DISCRETE_FACE_H_
 #define _DISCRETE_FACE_H_
@@ -9,6 +9,7 @@
 #include "GmshConfig.h"
 #include "GModel.h"
 #include "GFace.h"
+#include "discreteVertex.h"
 #include "discreteEdge.h"
 #include "MTriangle.h"
 #include "MElementCut.h"
