@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #include <stack>
 #include <cmath>
@@ -606,21 +606,30 @@ void recur_tag(BDS_Face *t, BDS_GeomEntity *g)
   std::stack<BDS_Face *> _stack;
   _stack.push(t);
 
+  //  BDS_Point *pts[4];
+  //  t->getNodes(pts);
+  //  printf("starting with trioangle %d %d %d\n",pts[0]->iD,pts[1]->iD,pts[2]->iD);
+
   while(!_stack.empty()) {
     t = _stack.top();
     _stack.pop();
     if(!t->g) {
+      //      t->getNodes(pts);
+      //      printf("now in trioangle %d %d %d\n",pts[0]->iD,pts[1]->iD,pts[2]->iD);
       t->g = g;
       // g->t.push_back(t);
       if(!t->e1->g && t->e1->numfaces() == 2) {
+	//	printf("going through %d %d\n",t->e1->p1->iD,t->e1->p2->iD);
         _stack.push(t->e1->otherFace(t));
         //	recur_tag(t->e1->otherFace(t), g);
       }
       if(!t->e2->g && t->e2->numfaces() == 2) {
+	//	printf("going through %d %d\n",t->e2->p1->iD,t->e2->p2->iD);
         _stack.push(t->e2->otherFace(t));
         //	recur_tag(t->e2->otherFace(t), g);
       }
       if(!t->e3->g && t->e3->numfaces() == 2) {
+	//	printf("going through %d %d\n",t->e3->p1->iD,t->e3->p2->iD);
         _stack.push(t->e3->otherFace(t));
         //	recur_tag(t->e3->otherFace(t), g);
       }
@@ -699,10 +708,10 @@ bool BDS_Mesh::split_edge(BDS_Edge *e, BDS_Point *mid)
 
   e->oppositeof(op);
 
-  int CHECK1 = -1, CHECK2 = -1;
+  int CHECK1 = -1, CHECK2 = 46;
 
   if(p1->iD == CHECK1 && p2->iD == CHECK2)
-    printf("coucou %d %d %d %d\n", p1->iD, p2->iD, op[0]->iD, op[1]->iD);
+    printf("splitting edge %d %d opp %d %d new %d\n", p1->iD, p2->iD, op[0]->iD, op[1]->iD,mid->iD);
 
   double ori0 = fabs(surface_triangle_param(p2, p1, op[0])) +
                 fabs(surface_triangle_param(p2, p1, op[1]));
@@ -852,7 +861,8 @@ bool BDS_SwapEdgeTestQuality::operator()(BDS_Point *_p1, BDS_Point *_p2,
   if(fabs(s1 + s2 - s3 - s4) > 1.e-12 * (s3 + s4)) {
     return false;
   }
-  if(s3 < .02 * (s1 + s2) || s4 < .02 * (s1 + s2)) return false;
+  // THIS WAS CAUSIN' TROUBLES ...
+  //if(s3 < .02 * (s1 + s2) || s4 < .02 * (s1 + s2)) return false;
 
   /*
   if(!testSmallTriangles) {
@@ -983,7 +993,7 @@ bool BDS_SwapEdgeTestNormals::operator()(BDS_Point *_p1, BDS_Point *_p2,
   if(fabs(s1 + s2 - s3 - s4) > 1.e-12 * (s3 + s4)) {
     return false;
   }
-  if(s3 < .02 * (s1 + s2) || s4 < .02 * (s1 + s2)) return false;
+  //  if(s3 < .02 * (s1 + s2) || s4 < .02 * (s1 + s2)) return false;
   return true;
 }
 
@@ -1032,7 +1042,9 @@ bool BDS_Mesh::swap_edge(BDS_Edge *e, const BDS_SwapEdgeTest &theTest,
    */
 
   // we test if the edge is deleted
-  //  return false;
+  //return false;
+
+
 
   BDS_Point *p1 = e->p1;
   BDS_Point *p2 = e->p2;
@@ -1397,7 +1409,8 @@ bool BDS_Mesh::collapse_edge_parametric(BDS_Edge *e, BDS_Point *p, bool force)
 
 bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool test_quality)
 {
- //  printf("coucou\n");
+  //  return true;
+  //  printf("coucou\n");
  //  if(!p->config_modified) return false;
  if(p->g && p->g->classif_degree <= 1) return false;
  if(p->g && p->g->classif_tag < 0) {
@@ -1598,8 +1611,8 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool hard)
   eit = p->edges.begin();
 
   if(eit == itede) {
-    Msg::Debug("Hidden bug ... I should have deleted a point but I still do "
-               "not know why it segfault when I do it :-) ");
+    // Msg::Debug("Hidden bug ... I should have deleted a point but I still do "
+    //            "not know why it segfault when I do it :-) ");
     return false;
   }
 
@@ -1625,8 +1638,8 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool hard)
     ++eit;
   }
   if(p->iD == CHECK) printf("\n");
-  //  printf("%g\n",fact);
-  //  sTot *= fact;
+  // printf("%g\n",fact);
+  // sTot *= fact;
   U /= (fact);
   V /= (fact);
   LC /= (sTot);
@@ -1634,19 +1647,7 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool hard)
   YY /= (sTot);
   ZZ /= (sTot);
 
-  GPoint gp;
-
-  /**  if (gf->geomType() == GEntity::DiscreteSurface){
-       SVector3 normal;
-       discreteFace *df = static_cast<discreteFace*> (gf);
-       if (df){
-       gp = df->closestPoint(SPoint3(XX, YY, ZZ), LC,&normal);
-       U = gp.u();
-       V = gp.v();
-       }
-       }
-       else*/
-  gp = gf->point(U, V);
+  GPoint gp = gf->point(U, V);
 
   if(!gp.succeeded()) {
     return false;
@@ -1729,20 +1730,20 @@ bool BDS_Mesh::smooth_point_centroid(BDS_Point *p, GFace *gf, bool hard)
     ++it;
   }
 
-  //  if (p->edges.size() == 3)printf("3 -> %22.15E\n",fabs(s2-s1));
+  // if(p->edges.size() == 3)printf("3 -> %22.15E\n", fabs(s2-s1));
   if(fabs(s2 - s1) > 1.e-12 * (s2 + s1)) {
-    //    if (p->iD == CHECK)
-    //    printf("PARAMETRIC TRIANGLES OVERLAP %22.15E!!\n",fabs(s2-s1));
-    //    else
+    // if(p->iD == CHECK)
+    //   printf("PARAMETRIC TRIANGLES OVERLAP %22.15E!!\n", fabs(s2-s1));
+    // else
     return false;
   }
   if(newWorst < oldWorst) return false;
-  //  if (p->edges.size() == 3)printf("OK \n");
+  // if (p->edges.size() == 3) printf("OK \n");
 
-  //  if (OLD < 0 && NEW > OLD){
-  //    return true;
-  //  }
-  //  if (NEW < 0)return false;
+  // if(OLD < 0 && NEW > OLD){
+  //   return true;
+  // }
+  // if(NEW < 0) return false;
 
   p->u = U;
   p->v = V;
