@@ -1,7 +1,7 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
 #include <stdlib.h>
 #include <stack>
@@ -311,9 +311,9 @@ static void Mesh0D(GModel *m)
   }
   for(GModel::viter it = m->firstVertex(); it != m->lastVertex(); ++it) {
     GVertex *gv = *it;
-    if(gv->meshMaster() != gv) {
+    if(gv->getMeshMaster() != gv) {
       if(gv->correspondingVertices.empty()) {
-        GVertex *master = dynamic_cast<GVertex *>(gv->meshMaster());
+        GVertex *master = dynamic_cast<GVertex *>(gv->getMeshMaster());
         if(master)
           gv->correspondingVertices[gv->mesh_vertices[0]] =
             master->mesh_vertices[0];
@@ -488,6 +488,9 @@ static void Mesh2D(GModel *m)
         if(!nIter) Msg::ProgressMeter(nPending, nTot, false, "Meshing 2D...");
       }
       if(!nPending) break;
+      // iter == 2 is for meshing re-parametrized surfaces
+      // after that, we serialize (self-intersections of 1D meshes are not thread safe)!
+      if(nIter > 2) Msg::SetNumThreads(1);
       if(nIter++ > 10) break;
     }
   }
@@ -542,7 +545,7 @@ FindConnectedRegions(const std::vector<GRegion *> &del,
     connected.push_back(temp2);
     delaunay = temp1;
   }
-  Msg::Info("Delaunay Meshing %d volumes with %d connected components",
+  Msg::Info("3D Meshing %d volumes with %d connected components",
             nbVolumes, connected.size());
 }
 
@@ -879,7 +882,7 @@ static void Mesh3D(GModel *m)
       if(treat_region_ok && (CTX::instance()->mesh.recombine3DAll ||
                              gr->meshAttributes.recombine3D)) {
         if(CTX::instance()->mesh.optimize) {
-          optimizeMeshGRegionGmsh opt;
+          optimizeMeshGRegion opt;
           opt(gr);
         }
         double a = Cpu();
@@ -987,7 +990,7 @@ void OptimizeMesh(GModel *m)
   Msg::StatusBar(true, "Optimizing 3D mesh...");
   double t1 = Cpu();
 
-  std::for_each(m->firstRegion(), m->lastRegion(), optimizeMeshGRegionGmsh());
+  std::for_each(m->firstRegion(), m->lastRegion(), optimizeMeshGRegion());
   // Ensure that all volume Jacobians are positive
   m->setAllVolumesPositive();
 
@@ -1094,7 +1097,7 @@ void GenerateMesh(GModel *m, int ask)
     std::for_each(m->firstFace(), m->lastFace(), orientMeshGFace());
 
   // Optimize quality of 3D tet mesh
-  if(m->getMeshStatus() == 3) {
+  if(m->getMeshStatus() == 3 && CTX::instance()->mesh.algo3d != ALGO_3D_HXT) {
     for(int i = 0; i < std::max(CTX::instance()->mesh.optimize,
                                 CTX::instance()->mesh.optimizeNetgen);
         i++) {
