@@ -1,10 +1,10 @@
 // Gmsh - Copyright (C) 1997-2018 C. Geuzaine, J.-F. Remacle
 //
 // See the LICENSE.txt file for license information. Please report all
-// bugs and problems to the public mailing list <gmsh@onelab.info>.
+// issues on https://gitlab.onelab.info/gmsh/gmsh/issues
 
-#ifndef _MESH_GREGION_HXT_
-#define _MESH_GREGION_HXT_
+#ifndef _MESH_GREGION_HXT_H_
+#define _MESH_GREGION_HXT_H_
 
 #include <vector>
 
